# L3 Network Simulator repository


### Tutorial




### Cluster requirements (Не актуальные)
* Всё запускается от рута
* У рута должен быть доступ без пароля на руты всех узлов кластера
* wg
* /tmp/l3ns
